==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/outputs/MonthlyScheduleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Monthly Schedule properties
 * @property daysOfMonth Indicates which days of the month snapshot should be taken. A comma delimited string.
 * @property hour Indicates which hour in UTC timezone a snapshot should be taken
 * @property minute Indicates which minute snapshot should be taken
 * @property snapshotsToKeep Monthly snapshot count to keep
 * @property usedBytes Resource size in bytes, current storage usage for the volume in bytes
 */
public data class MonthlyScheduleResponse(
    public val daysOfMonth: String? = null,
    public val hour: Int? = null,
    public val minute: Int? = null,
    public val snapshotsToKeep: Int? = null,
    public val usedBytes: Double? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.netapp.outputs.MonthlyScheduleResponse):
            MonthlyScheduleResponse = MonthlyScheduleResponse(
            daysOfMonth = javaType.daysOfMonth().map({ args0 -> args0 }).orElse(null),
            hour = javaType.hour().map({ args0 -> args0 }).orElse(null),
            minute = javaType.minute().map({ args0 -> args0 }).orElse(null),
            snapshotsToKeep = javaType.snapshotsToKeep().map({ args0 -> args0 }).orElse(null),
            usedBytes = javaType.usedBytes().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/outputs/MonthlyScheduleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Monthly Schedule properties
 * @property daysOfMonth Indicates which days of the month snapshot should be taken. A comma delimited string.
 * @property hour Indicates which hour in UTC timezone a snapshot should be taken
 * @property minute Indicates which minute snapshot should be taken
 * @property snapshotsToKeep Monthly snapshot count to keep
 * @property usedBytes Resource size in bytes, current storage usage for the volume in bytes
 */
public data class MonthlyScheduleResponse(
    public val daysOfMonth: String? = null,
    public val hour: Int? = null,
    public val minute: Int? = null,
    public val snapshotsToKeep: Int? = null,
    public val usedBytes: Double? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.netapp.outputs.MonthlyScheduleResponse): MonthlyScheduleResponse = MonthlyScheduleResponse(
            daysOfMonth = javaType.daysOfMonth().map({ args0 -> args0 }).orElse(null),
            hour = javaType.hour().map({ args0 -> args0 }).orElse(null),
            minute = javaType.minute().map({ args0 -> args0 }).orElse(null),
            snapshotsToKeep = javaType.snapshotsToKeep().map({ args0 -> args0 }).orElse(null),
            usedBytes = javaType.usedBytes().map({ args0 -> args0 }).orElse(null),
        )
    }
}
